@@ -1,6 +1,7 @@
 import sys
 
 import click
+
 from elementary.config.config import Config
 from elementary.monitor.data_monitoring import DataMonitoring
 from elementary.tracking.anonymous_tracking import AnonymousTracking
@@ -15,6 +16,12 @@ logger = get_logger(__name__)
 
 # Displayed in reverse order in --help.
 def common_options(func):
+    func = click.option(
+        "--disable-samples",
+        type=bool,
+        default=False,
+        help="Disable sampling of data. Useful if your data contains PII.",
+    )(func)
     func = click.option(
         "--dbt-quoting",
         "-dq",
@@ -39,6 +46,12 @@ def common_options(func):
         default=7,
         help="Set a limit to how far back should edr collect data.",
     )(func)
+    func = click.option(
+        "--env",
+        type=click.Choice(["dev", "prod"]),
+        default="dev",
+        help="This flag indicates if you are running Elementary in prod or dev environment and will be reflected accordingly in the report.",
+    )(func)
     func = click.option(
         "--config-dir",
         "-c",
@@ -52,13 +65,13 @@ def common_options(func):
         "-t",
         type=str,
         default=None,
-        help="if you have multiple targets for Elementary, optionally use this flag to choose a specific target.",
+        help="If you have multiple targets for Elementary, optionally use this flag to choose a specific target.",
     )(func)
     func = click.option(
         "--profiles-dir",
         "-p",
         type=str,
-        default=Config.DEFAULT_PROFILES_DIR,
+        default=None,
         help="Specify your profiles dir where a profiles.yml is located, this could be a dbt profiles dir "
         "(if your profiles dir is ~/.dbt, no need to provide this parameter as we use it as default).",
     )(func)
@@ -131,9 +144,9 @@ def get_cli_properties() -> dict:
 )
 @click.option(
     "--test",
-    type=str,
-    default=None,
-    help="Specify raw YAML string of your dbt variables.",
+    type=bool,
+    default=False,
+    help="Whether to send a test message in case there are no alerts.",
 )
 @click.pass_context
 def monitor(
@@ -151,6 +164,8 @@ def monitor(
     profile_target,
     dbt_vars,
     test,
+    disable_samples,
+    env,
 ):
     """
     Monitor your warehouse.
@@ -168,6 +183,7 @@ def monitor(
         slack_token=slack_token,
         slack_channel_name=slack_channel_name,
         timezone=timezone,
+        env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
     anonymous_tracking.track_cli_start(
@@ -180,8 +196,9 @@ def monitor(
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
             send_test_message_on_success=test,
+            disable_samples=disable_samples,
         )
-        success = data_monitoring.run(
+        success = data_monitoring.run_alerts(
             days_back, full_refresh_dbt_package, dbt_vars=vars
         )
         anonymous_tracking.track_cli_end(
@@ -226,6 +243,11 @@ def monitor(
     default=True,
     help="Exclude Elementary's internal models from the report.",
 )
+@click.option(
+    "--project-name",
+    type=str,
+    help="The project name to display in the report.",
+)
 @click.pass_context
 def report(
     ctx,
@@ -240,6 +262,9 @@ def report(
     disable_passed_test_metrics,
     open_browser,
     exclude_elementary_models,
+    disable_samples,
+    project_name,
+    env,
 ):
     """
     Generate a local report of your warehouse.
@@ -249,6 +274,7 @@ def report(
         profiles_dir,
         profile_target,
         dbt_quoting=dbt_quoting,
+        env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
     anonymous_tracking.track_cli_start(
@@ -260,6 +286,7 @@ def report(
             config=config,
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
+            disable_samples=disable_samples,
         )
         generated_report_successfully, _ = data_monitoring.generate_report(
             days_back=days_back,
@@ -268,6 +295,7 @@ def report(
             disable_passed_test_metrics=disable_passed_test_metrics,
             exclude_elementary_models=exclude_elementary_models,
             should_open_browser=open_browser,
+            project_name=project_name,
         )
         anonymous_tracking.track_cli_end(
             "monitor-report", data_monitoring.properties(), ctx.command.name
@@ -371,6 +399,11 @@ def report(
     default=True,
     help="Exclude Elementary's internal models from the report.",
 )
+@click.option(
+    "--project-name",
+    type=str,
+    help="The project name to display in the report.",
+)
 @click.pass_context
 def send_report(
     ctx,
@@ -395,6 +428,9 @@ def send_report(
     google_project_name,
     gcs_bucket_name,
     exclude_elementary_models,
+    disable_samples,
+    project_name,
+    env,
 ):
     """
     Send the report to an external platform.
@@ -417,6 +453,7 @@ def send_report(
         google_service_account_path=google_service_account_path,
         google_project_name=google_project_name,
         gcs_bucket_name=gcs_bucket_name,
+        env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
     anonymous_tracking.track_cli_start(
@@ -435,6 +472,7 @@ def send_report(
             config=config,
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
+            disable_samples=disable_samples,
         )
         command_succeeded = False
         (
@@ -447,6 +485,7 @@ def send_report(
             file_path=local_file_path,
             should_open_browser=False,
             exclude_elementary_models=exclude_elementary_models,
+            project_name=project_name,
         )
         if generated_report_successfully and elementary_html_path:
             command_succeeded = data_monitoring.send_report(
