@@ -1,39 +1,53 @@
 import json
 import os
 import os.path
+import re
 import webbrowser
 from collections import defaultdict
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Union
 
+import click
 import pkg_resources
 from alive_progress import alive_it
+from packaging import version
 
 from elementary.clients.dbt.dbt_runner import DbtRunner
 from elementary.clients.gcs.client import GCSClient
 from elementary.clients.s3.client import S3Client
 from elementary.clients.slack.client import SlackClient
+from elementary.clients.slack.schema import SlackMessageSchema
 from elementary.config.config import Config
 from elementary.monitor import dbt_project_utils
 from elementary.monitor.alerts.alert import Alert
 from elementary.monitor.alerts.alerts import Alerts
 from elementary.monitor.alerts.model import ModelAlert
 from elementary.monitor.alerts.source_freshness import SourceFreshnessAlert
-from elementary.monitor.alerts.test import TestAlert, ElementaryTestAlert
+from elementary.monitor.alerts.test import ElementaryTestAlert, TestAlert
 from elementary.monitor.api.alerts import AlertsAPI
+from elementary.monitor.api.filters.filters import FiltersAPI
 from elementary.monitor.api.lineage.lineage import LineageAPI
 from elementary.monitor.api.lineage.schema import LineageSchema
 from elementary.monitor.api.models.models import ModelsAPI
+from elementary.monitor.api.models.schema import (
+    ModelRunsSchema,
+    NormalizedExposureSchema,
+    NormalizedModelSchema,
+    NormalizedSourceSchema,
+)
+from elementary.monitor.api.sidebar.schema import SidebarsSchema
 from elementary.monitor.api.sidebar.sidebar import SidebarAPI
 from elementary.monitor.api.tests.schema import (
     InvocationSchema,
     ModelUniqueIdType,
     TestMetadataSchema,
     TestUniqueIdType,
+    TotalsSchema,
 )
 from elementary.monitor.api.tests.tests import TestsAPI
 from elementary.tracking.anonymous_tracking import AnonymousTracking
 from elementary.utils import package
+from elementary.utils.json_utils import parse_str_to_list, prettify_json_str_set
 from elementary.utils.log import get_logger
 from elementary.utils.time import get_now_utc_iso_format
 
@@ -50,6 +64,7 @@ class DataMonitoring:
         tracking: AnonymousTracking,
         force_update_dbt_package: bool = False,
         send_test_message_on_success: bool = False,
+        disable_samples: bool = False,
     ):
         self.config = config
         self.tracking = tracking
@@ -59,8 +74,18 @@ class DataMonitoring:
             self.config.profile_target,
             dbt_env_vars=self.config.dbt_env_vars,
         )
+        self.tests_api = TestsAPI(dbt_runner=self.dbt_runner)
+        self.models_api = ModelsAPI(dbt_runner=self.dbt_runner)
+        self.sidebar_api = SidebarAPI(dbt_runner=self.dbt_runner)
+        self.lineage_api = LineageAPI(dbt_runner=self.dbt_runner)
+        self.filter_api = FiltersAPI(dbt_runner=self.dbt_runner)
         self.execution_properties = {}
-        dbt_pkg_version = self.get_elementary_dbt_pkg_version()
+        latest_invocation = self.get_latest_invocation()
+        self.project_name = latest_invocation.get("project_name")
+        tracking.set_env("target_name", latest_invocation.get("target_name"))
+        tracking.set_env("dbt_orchestrator", latest_invocation.get("orchestrator"))
+        tracking.set_env("dbt_version", latest_invocation.get("dbt_version"))
+        dbt_pkg_version = latest_invocation.get("elementary_version")
         tracking.set_env("dbt_pkg_version", dbt_pkg_version)
         if dbt_pkg_version:
             self._check_dbt_package_compatibility(dbt_pkg_version)
@@ -78,6 +103,29 @@ class DataMonitoring:
         self.sent_alert_count = 0
         self.success = True
         self.send_test_message_on_success = send_test_message_on_success
+        self.disable_samples = disable_samples
+
+    def _parse_emails_to_ids(self, slack_members: Union[str, List[str]]) -> str:
+        if not slack_members:
+            return slack_members
+
+        def _regex_match_owner_email(potential_email: str) -> bool:
+            email_regex = r"\b[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Z|a-z]{2,}\b"
+            return bool(re.fullmatch(email_regex, potential_email))
+
+        def _get_user_id(email: str) -> str:
+            user_id = self.slack_client.get_user_id_from_email(email)
+            return f"<@{user_id}>" if user_id else email
+
+        if isinstance(slack_members, str):
+            slack_members = parse_str_to_list(slack_members)
+        ids = [
+            _get_user_id(slack_member)
+            if _regex_match_owner_email(slack_member)
+            else slack_member
+            for slack_member in slack_members
+        ]
+        return prettify_json_str_set(ids)
 
     def _send_alerts_to_slack(self, alerts: List[Alert], alerts_table_name: str):
         if not alerts:
@@ -86,6 +134,8 @@ class DataMonitoring:
         sent_alert_ids = []
         alerts_with_progress_bar = alive_it(alerts, title="Sending alerts")
         for alert in alerts_with_progress_bar:
+            alert.owners = self._parse_emails_to_ids(alert.owners)
+            alert.subscribers = self._parse_emails_to_ids(alert.subscribers)
             alert_msg = alert.to_slack()
             sent_successfully = self.slack_client.send_message(
                 channel_name=alert.slack_channel
@@ -121,8 +171,11 @@ class DataMonitoring:
     def _send_test_message(self):
         self.slack_client.send_message(
             channel_name=self.config.slack_channel_name,
-            message=f"Elementary monitor ran successfully on {datetime.now().strftime('%Y-%m-%d %H:%M')}",
+            message=SlackMessageSchema(
+                text=f"Elementary monitor ran successfully on {datetime.now().strftime('%Y-%m-%d %H:%M')}"
+            ),
         )
+        logger.info("Sent the test message.")
 
     def _send_alerts(self, alerts: Alerts):
         self._send_alerts_to_slack(alerts.tests.get_all(), TestAlert.TABLE_NAME)
@@ -132,7 +185,7 @@ class DataMonitoring:
         )
         self.execution_properties["sent_alert_count"] = self.sent_alert_count
 
-    def run(
+    def run_alerts(
         self,
         days_back: int,
         dbt_full_refresh: bool = False,
@@ -149,7 +202,7 @@ class DataMonitoring:
             self.execution_properties["success"] = self.success
             return self.success
 
-        alerts = self.alerts_api.query(days_back)
+        alerts = self.alerts_api.query(days_back, disable_samples=self.disable_samples)
         self.execution_properties[
             "elementary_test_count"
         ] = alerts.get_elementary_test_count()
@@ -176,11 +229,21 @@ class DataMonitoring:
         disable_passed_test_metrics: bool = False,
         should_open_browser: bool = True,
         exclude_elementary_models: bool = False,
+        project_name: Optional[str] = None,
     ) -> Tuple[bool, str]:
         now_utc = get_now_utc_iso_format()
         html_path = self._get_report_file_path(now_utc, file_path)
         with open(html_path, "w") as html_file:
             output_data = {"creation_time": now_utc, "days_back": days_back}
+
+            models = self.models_api.get_models(exclude_elementary_models)
+            sources = self.models_api.get_sources()
+            exposures = self.models_api.get_exposures()
+            tests_metadata = self.tests_api.get_tests_metadata(days_back=days_back)
+            models_runs = self.models_api.get_models_runs(
+                days_back=days_back, exclude_elementary_models=exclude_elementary_models
+            )
+
             (
                 test_results,
                 test_results_totals,
@@ -189,23 +252,31 @@ class DataMonitoring:
                 days_back=days_back,
                 test_runs_amount=test_runs_amount,
                 disable_passed_test_metrics=disable_passed_test_metrics,
+                tests_metadata=tests_metadata,
             )
-            models, dbt_sidebar = self._get_dbt_models_and_sidebar(
-                exclude_elementary_models
+            serializable_models, sidebars = self._get_dbt_models_and_sidebars(
+                models, sources, exposures
             )
             models_coverages = self._get_dbt_models_test_coverages()
-            models_runs, model_runs_totals = self._get_models_runs_and_totals(
-                days_back=days_back, exclude_elementary_models=exclude_elementary_models
+            models_runs_dicts, model_runs_totals = self._get_models_runs_and_totals(
+                models_runs
             )
             lineage = self._get_lineage(exclude_elementary_models)
-            output_data["models"] = models
-            output_data["dbt_sidebar"] = dbt_sidebar
+            filters = self.filter_api.get_filters(
+                test_results_totals, test_runs_totals, models, sources, models_runs
+            )
+
+            output_data["models"] = serializable_models
+            output_data["sidebars"] = sidebars.dict()
             output_data["test_results"] = test_results
-            output_data["test_results_totals"] = test_results_totals
-            output_data["test_runs_totals"] = test_runs_totals
+            output_data["test_results_totals"] = self._serialize_totals(
+                test_results_totals
+            )
+            output_data["test_runs_totals"] = self._serialize_totals(test_runs_totals)
             output_data["coverages"] = models_coverages
-            output_data["model_runs"] = models_runs
+            output_data["model_runs"] = models_runs_dicts
             output_data["model_runs_totals"] = model_runs_totals
+            output_data["filters"] = filters.dict()
             output_data["lineage"] = lineage.dict()
             output_data["tracking"] = {
                 "posthog_api_key": self.tracking.POSTHOG_PROJECT_API_KEY,
@@ -214,6 +285,10 @@ class DataMonitoring:
                 if self.tracking.anonymous_warehouse
                 else None,
             }
+            output_data["env"] = {
+                "project_name": project_name or self.project_name,
+                "env": self.config.env,
+            }
             template_html_path = pkg_resources.resource_filename(__name__, "index.html")
             with open(template_html_path, "r") as template_html_file:
                 template_html_code = template_html_file.read()
@@ -231,7 +306,11 @@ class DataMonitoring:
             elementary_output_json_file.write(dumped_output_data)
 
         if should_open_browser:
-            webbrowser.open_new_tab("file://" + html_path)
+            try:
+                webbrowser.open_new_tab("file://" + html_path)
+            except webbrowser.Error as e:
+                logger.error("Unable to open the web browser.")
+
         self.execution_properties["report_end"] = True
         self.execution_properties["success"] = self.success
         return self.success, html_path
@@ -267,23 +346,24 @@ class DataMonitoring:
         return self.success
 
     def _get_lineage(self, exclude_elementary_models: bool = False) -> LineageSchema:
-        lineage_api = LineageAPI(dbt_runner=self.dbt_runner)
-        return lineage_api.get_lineage(exclude_elementary_models)
+        return self.lineage_api.get_lineage(exclude_elementary_models)
 
     def _get_test_results_and_totals(
         self,
+        tests_metadata: Optional[List[TestMetadataSchema]],
         days_back: Optional[int] = None,
         test_runs_amount: Optional[int] = None,
         disable_passed_test_metrics: bool = False,
     ):
-        tests_api = TestsAPI(dbt_runner=self.dbt_runner)
         try:
-            tests_metadata = tests_api.get_tests_metadata(days_back=days_back)
-            tests_sample_data = tests_api.get_tests_sample_data(
-                days_back=days_back,
-                disable_passed_test_metrics=disable_passed_test_metrics,
-            )
-            invocations = tests_api.get_invocations(
+            if self.disable_samples:
+                tests_sample_data = {}
+            else:
+                tests_sample_data = self.tests_api.get_tests_sample_data(
+                    days_back=days_back,
+                    disable_passed_test_metrics=disable_passed_test_metrics,
+                )
+            invocations = self.tests_api.get_invocations(
                 invocations_per_test=test_runs_amount, days_back=days_back
             )
             tests_results = self._create_tests_results(
@@ -291,8 +371,8 @@ class DataMonitoring:
                 tests_sample_data=tests_sample_data,
                 invocations=invocations,
             )
-            test_results_totals = tests_api.get_total_tests_results(tests_metadata)
-            test_runs_totals = tests_api.get_total_tests_runs(
+            test_results_totals = self.tests_api.get_total_tests_results(tests_metadata)
+            test_runs_totals = self.tests_api.get_total_tests_runs(
                 tests_metadata=tests_metadata, tests_invocations=invocations
             )
             self.execution_properties["test_result_count"] = len(tests_metadata)
@@ -312,7 +392,9 @@ class DataMonitoring:
         elementary_test_count = defaultdict(int)
         tests_results = defaultdict(list)
         for test in tests_metadata:
-            test_sub_type_unique_id = TestsAPI.get_test_sub_type_unique_id(**dict(test))
+            test_sub_type_unique_id = self.tests_api.get_test_sub_type_unique_id(
+                **dict(test)
+            )
             metadata = dict(test)
             test_sample_data = tests_sample_data.get(test_sub_type_unique_id)
             test_invocations = invocations.get(test_sub_type_unique_id)
@@ -332,13 +414,14 @@ class DataMonitoring:
         self.execution_properties["elementary_test_count"] = elementary_test_count
         return tests_results
 
-    def _get_models_runs_and_totals(
-        self, days_back: Optional[int] = None, exclude_elementary_models: bool = False
-    ):
-        models_api = ModelsAPI(dbt_runner=self.dbt_runner)
-        models_runs = models_api.get_models_runs(
-            days_back=days_back, exclude_elementary_models=exclude_elementary_models
-        )
+    @staticmethod
+    def _serialize_totals(totals: Dict[str, TotalsSchema]) -> Dict[str, dict]:
+        serialized_totals = dict()
+        for model_unique_id, total in totals.items():
+            serialized_totals[model_unique_id] = total.dict()
+        return serialized_totals
+
+    def _get_models_runs_and_totals(self, models_runs: List[ModelRunsSchema]):
         models_runs_dicts = []
         model_runs_totals = {}
         for model_runs in models_runs:
@@ -346,21 +429,17 @@ class DataMonitoring:
             model_runs_totals[model_runs.unique_id] = {
                 "errors": model_runs.totals.errors,
                 "warnings": 0,
-                "resolved": 0,
+                "failures": 0,
                 "passed": model_runs.totals.success,
             }
         return models_runs_dicts, model_runs_totals
 
-    def _get_dbt_models_and_sidebar(
-        self, exclude_elementary_models: bool = False
-    ) -> Tuple[Dict, Dict]:
-        models_api = ModelsAPI(dbt_runner=self.dbt_runner)
-        sidebar_api = SidebarAPI(dbt_runner=self.dbt_runner)
-
-        models = models_api.get_models(exclude_elementary_models)
-        sources = models_api.get_sources()
-        exposures = models_api.get_exposures()
-
+    def _get_dbt_models_and_sidebars(
+        self,
+        models: Dict[str, NormalizedModelSchema],
+        sources: Dict[str, NormalizedSourceSchema],
+        exposures: Dict[str, NormalizedExposureSchema],
+    ) -> Tuple[Dict, SidebarsSchema]:
         self.execution_properties["model_count"] = len(models)
         self.execution_properties["source_count"] = len(sources)
         self.execution_properties["exposure_count"] = len(exposures)
@@ -371,13 +450,14 @@ class DataMonitoring:
             serializable_nodes[key] = dict(nodes[key])
 
         # Currently we don't show exposures as part of the sidebar
-        dbt_sidebar = sidebar_api.get_sidebar(models=models, sources=sources)
+        sidebars = self.sidebar_api.get_sidebars(
+            artifacts=[*models.values(), *sources.values()]
+        )
 
-        return serializable_nodes, dbt_sidebar
+        return serializable_nodes, sidebars
 
     def _get_dbt_models_test_coverages(self) -> Dict[str, Dict[str, int]]:
-        models_api = ModelsAPI(dbt_runner=self.dbt_runner)
-        coverages = models_api.get_test_coverages()
+        coverages = self.models_api.get_test_coverages()
         return {model_id: dict(coverage) for model_id, coverage in coverages.items()}
 
     def properties(self):
@@ -412,21 +492,30 @@ class DataMonitoring:
             self.tracking.record_cli_internal_exception(ex)
             return "<elementary_database>.<elementary_schema>"
 
-    def get_elementary_dbt_pkg_version(self) -> Optional[str]:
+    def get_latest_invocation(self) -> Dict[str, Any]:
         try:
-            dbt_pkg_version = self.dbt_runner.run_operation(
-                "get_elementary_dbt_pkg_version", quiet=True
+            latest_invocation = self.dbt_runner.run_operation(
+                "get_latest_invocation", quiet=True
             )[0]
-            return dbt_pkg_version or None
+            return json.loads(latest_invocation)[0] if latest_invocation else {}
         except Exception as err:
-            logger.error(f"Unable to get Elementary's dbt package version: {err}")
+            logger.error(f"Unable to get the latest invocation: {err}")
             self.tracking.record_cli_internal_exception(err)
-            return None
+            return {}
 
-    def _check_dbt_package_compatibility(self, dbt_pkg_version: str):
-        logger.info("Checking compatibility between edr and Elementary's dbt package.")
-        try:
-            package.check_dbt_pkg_compatible(dbt_pkg_version)
-        except Exception as err:
-            logger.error(f"Failed to check compatibility with dbt package: {err}")
-            self.tracking.record_cli_internal_exception(err)
+    @staticmethod
+    def _check_dbt_package_compatibility(dbt_pkg_ver: str):
+        dbt_pkg_ver = version.parse(dbt_pkg_ver)
+        py_pkg_ver = version.parse(package.get_package_version())
+        logger.info(
+            f"Checking compatibility between edr ({py_pkg_ver}) and Elementary's dbt package ({dbt_pkg_ver})."
+        )
+        if (
+            dbt_pkg_ver.major != py_pkg_ver.major
+            or dbt_pkg_ver.minor != py_pkg_ver.minor
+        ):
+            click.secho(
+                f"You are using incompatible versions between edr ({py_pkg_ver}) and Elementary's dbt package ({dbt_pkg_ver}).\n "
+                "Please upgrade the major and minor versions to align.\n",
+                fg="yellow",
+            )
